@@ -163,12 +163,10 @@ class XmltvGenerator:
         missing_desc_count = 0
 
         # Configuration values
-        use_extended_desc = config.get("xdesc", False)  # Use extended series description
-        use_extended_details = config.get("xdetails", False)  # Add extra details (• S37E13 | CC)
-        use_actor_photos = config.get("xdetails", False)  # Actor photos with extended details
-        need_extended_download = (
-            use_extended_desc or use_extended_details
-        )  # Download if either is true
+        use_extended_desc = config.get(
+            "xdesc", False
+        )  # Use extended series description AND add enhanced info
+        use_extended_details = config.get("xdetails", False)  # Download extended details from API
         safe_titles = config.get("stitle", False)
         ep_genre = config.get("epgenre", "3")
         ep_icon = config.get("epicon", "1")
@@ -176,7 +174,9 @@ class XmltvGenerator:
         try:
             logging.info("Writing Episodes to xmltv.xml file...")
             logging.info(
-                "Configuration: xdesc=%s, xdetails=%s", use_extended_desc, use_extended_details
+                "Configuration: xdesc=%s (controls description selection and enhanced info), xdetails=%s (controls API download)",
+                use_extended_desc,
+                use_extended_details,
             )
 
             # Count total episodes for progress tracking
@@ -238,7 +238,7 @@ class XmltvGenerator:
 
                         if self.language_detector:
                             # Priority 1: Try to detect from extended description if available
-                            if use_extended_desc and need_extended_download:
+                            if use_extended_desc and use_extended_details:
                                 extended_desc = episode_data.get("epseriesdesc")
                                 if extended_desc and str(extended_desc).strip():
                                     detected_language = self.language_detector.detect_language(
@@ -255,11 +255,7 @@ class XmltvGenerator:
 
                         # Prepare description
                         final_description = self._prepare_description(
-                            episode_data,
-                            detected_language,
-                            use_extended_desc,
-                            use_extended_details,
-                            need_extended_download,
+                            episode_data, detected_language, use_extended_desc, use_extended_details
                         )
 
                         if final_description:
@@ -295,13 +291,13 @@ class XmltvGenerator:
                             )
 
                         # 4. CREDITS?
-                        self._write_credits_dtd_compliant(fh, episode_data, use_actor_photos)
+                        self._write_credits_dtd_compliant(fh, episode_data, use_extended_details)
 
                         # 5. DATE?
                         if episode_data.get("epyear"):
                             fh.write(f'\t\t<date>{episode_data["epyear"]}</date>\n')
 
-                        # 6. CATEGORY* - MODIFICATION: Passer detected_language
+                        # 6. CATEGORY*
                         self._write_categories(fh, episode_data, ep_genre, detected_language)
 
                         # 7. KEYWORD* (not used)
@@ -336,7 +332,7 @@ class XmltvGenerator:
                                     country_code = "US"
                             fh.write(f"\t\t<country>{country_code}</country>\n")
 
-                        # 14. EPISODE-NUM* (FIXED: Proper xmltv_ns format with spaces)
+                        # 14. EPISODE-NUM* (Proper xmltv_ns format with spaces)
                         dd_progid = episode_data.get("epid", "")
                         if dd_progid and len(dd_progid) >= 4:
                             fh.write(
@@ -458,13 +454,26 @@ class XmltvGenerator:
             logging.exception("Exception in _print_episodes: %s", str(e))
 
     def _write_credits_dtd_compliant(self, fh, episode_data: Dict, use_actor_photos: bool = True):
-        """Write cast and crew credits - DTD compliant with compact image formatting"""
+        """Write cast and crew credits - DTD compliant with proper ordering"""
         credits = episode_data.get("epcredits")
         if credits and isinstance(credits, list):
-            fh.write("\t\t<credits>\n")
 
-            # Valid DTD roles in order
-            valid_roles = {
+            # Valid DTD roles in STRICT ORDER as required by DTD
+            dtd_role_order = [
+                "director",
+                "actor",
+                "writer",
+                "adapter",
+                "producer",
+                "composer",
+                "editor",
+                "presenter",
+                "commentator",
+                "guest",
+            ]
+
+            # Map original roles to DTD roles
+            role_mapping = {
                 "director": "director",
                 "actor": "actor",
                 "writer": "writer",
@@ -475,11 +484,14 @@ class XmltvGenerator:
                 "presenter": "presenter",
                 "commentator": "commentator",
                 "guest": "guest",
-                "voice": "actor",
-                "narrator": "presenter",
-                "host": "presenter",
+                "voice": "actor",  # Map voice to actor
+                "narrator": "presenter",  # Map narrator to presenter
+                "host": "presenter",  # Map host to presenter
             }
 
+            # Group credits by DTD role type
+            grouped_credits = {role: [] for role in dtd_role_order}
+
             for credit in credits:
                 if isinstance(credit, dict):
                     original_role = credit.get("role", "").lower()
@@ -488,45 +500,71 @@ class XmltvGenerator:
                     asset_id = credit.get("assetId", "")
 
                     # Map to valid DTD role
-                    if original_role in valid_roles:
-                        dtd_role = valid_roles[original_role]
+                    if original_role in role_mapping and name:
+                        dtd_role = role_mapping[original_role]
+                        grouped_credits[dtd_role].append(
+                            {
+                                "name": name,
+                                "character": character,
+                                "asset_id": asset_id,
+                                "original_role": original_role,
+                            }
+                        )
 
-                        if dtd_role and name:
-                            # DTD compliant format with compact image formatting (no line breaks)
-                            if character and dtd_role == "actor":
-                                # Actor with character role
-                                fh.write(
-                                    f'\t\t\t<{dtd_role} role="{HtmlUtils.conv_html(character)}">'
-                                )
-                                fh.write(f"{HtmlUtils.conv_html(name)}")
+            # Check if we have any credits to write
+            has_credits = any(len(credits_list) > 0 for credits_list in grouped_credits.values())
 
-                                # Add image directly after name without line break
-                                if use_actor_photos and asset_id:
-                                    photo_url = f"https://zap2it.tmsimg.com/assets/{asset_id}.jpg"
-                                    fh.write(f'<image type="person">{photo_url}</image>')
+            if has_credits:
+                fh.write("\t\t<credits>\n")
 
-                                fh.write(f"</{dtd_role}>\n")
-                            else:
-                                # Other roles or actors without character
-                                fh.write(f"\t\t\t<{dtd_role}>")
-                                fh.write(f"{HtmlUtils.conv_html(name)}")
+                # Write credits in DTD-required order
+                for role in dtd_role_order:
+                    credits_for_role = grouped_credits[role]
 
-                                # Add image directly after name without line break
-                                if (
-                                    use_actor_photos
-                                    and asset_id
-                                    and dtd_role in ["actor", "director", "presenter"]
-                                ):
-                                    photo_url = f"https://zap2it.tmsimg.com/assets/{asset_id}.jpg"
-                                    fh.write(f'<image type="person">{photo_url}</image>')
+                    for credit_info in credits_for_role:
+                        name = credit_info["name"]
+                        character = credit_info["character"]
+                        asset_id = credit_info["asset_id"]
+                        original_role = credit_info["original_role"]
 
-                                fh.write(f"</{dtd_role}>\n")
+                        # DTD compliant format with compact image formatting
+                        if character and role == "actor":
+                            # Actor with character role
+                            fh.write(f'\t\t\t<{role} role="{HtmlUtils.conv_html(character)}">')
+                            fh.write(f"{HtmlUtils.conv_html(name)}")
 
-                            # Log mapping for visibility
-                            if original_role == "host":
-                                logging.debug("Host %s mapped to presenter (DTD compliant)", name)
+                            # Add image directly after name without line break
+                            if use_actor_photos and asset_id:
+                                photo_url = f"https://zap2it.tmsimg.com/assets/{asset_id}.jpg"
+                                fh.write(f'<image type="person">{photo_url}</image>')
 
-            fh.write("\t\t</credits>\n")
+                            fh.write(f"</{role}>\n")
+                        else:
+                            # Other roles or actors without character
+                            fh.write(f"\t\t\t<{role}>")
+                            fh.write(f"{HtmlUtils.conv_html(name)}")
+
+                            # Add image directly after name without line break
+                            if (
+                                use_actor_photos
+                                and asset_id
+                                and role in ["actor", "director", "presenter"]
+                            ):
+                                photo_url = f"https://zap2it.tmsimg.com/assets/{asset_id}.jpg"
+                                fh.write(f'<image type="person">{photo_url}</image>')
+
+                            fh.write(f"</{role}>\n")
+
+                        # Log mapping for visibility (debug level to avoid spam)
+                        if original_role != role:
+                            logging.debug(
+                                "Credit mapped: %s (%s) -> %s (DTD compliant)",
+                                name,
+                                original_role,
+                                role,
+                            )
+
+                fh.write("\t\t</credits>\n")
 
     def _write_enhanced_ratings(self, fh, episode_data: Dict):
         """Write enhanced rating information with MPAA system support"""
@@ -564,13 +602,26 @@ class XmltvGenerator:
         detected_language: str,
         use_extended_desc: bool,
         use_extended_details: bool,
-        need_extended_download: bool,
     ) -> Optional[str]:
-        """Prepare final description based on xdesc and xdetails settings"""
+        """
+        Prepare final description based on xdesc setting
+
+        Behavior:
+        - xdesc=false: Use basic guide description WITHOUT any enhanced info
+        - xdesc=true: Use extended series description (if available) WITH enhanced info
+
+        Args:
+            episode_data: Episode data dictionary
+            detected_language: Detected language for translations
+            use_extended_desc: Whether to use extended descriptions and add enhanced info (xdesc setting)
+            use_extended_details: Whether extended details were downloaded (xdetails setting)
+        """
         try:
             base_description = None
 
-            if use_extended_desc and need_extended_download:
+            # Select which description to use
+            if use_extended_desc and use_extended_details:
+                # xdesc=true AND xdetails=true: Try to use extended series description
                 extended_desc = episode_data.get("epseriesdesc")
                 if extended_desc and str(extended_desc).strip():
                     base_description = str(extended_desc).strip()
@@ -579,6 +630,7 @@ class XmltvGenerator:
                         episode_data.get("epshow", "Unknown"),
                     )
                 else:
+                    # Fall back to basic if extended not available
                     basic_desc = episode_data.get("epdesc")
                     base_description = str(basic_desc).strip() if basic_desc else ""
                     logging.debug(
@@ -586,22 +638,29 @@ class XmltvGenerator:
                         episode_data.get("epshow", "Unknown"),
                     )
             else:
-                # Use basic description from guide (shortDesc)
+                # xdesc=false OR xdetails=false: Use basic description from guide
                 basic_desc = episode_data.get("epdesc")
                 base_description = str(basic_desc).strip() if basic_desc else ""
                 logging.debug(
-                    "Using basic guide description for %s", episode_data.get("epshow", "Unknown")
+                    "Using basic guide description for %s (xdesc=%s, xdetails=%s)",
+                    episode_data.get("epshow", "Unknown"),
+                    use_extended_desc,
+                    use_extended_details,
                 )
 
-            # Add extended details if xdetails=true
+            # Only add enhanced info if xdesc=true
             if base_description:
-                if use_extended_details:
-                    # Add extra info (• S37E13 | CC, year, rating, etc.) from guide data
+                if use_extended_desc:
+                    # xdesc=true: Add enhanced info (year, rating, flags, etc.)
+                    # but WITHOUT S##E## as Kodi already displays it
                     return self._add_enhanced_info_to_basic_desc(
-                        base_description, episode_data, detected_language
+                        base_description,
+                        episode_data,
+                        detected_language,
+                        include_season_episode=False,
                     )
                 else:
-                    # Use description as-is
+                    # xdesc=false: Return description as-is, no enhancements
                     return base_description
 
             return None
@@ -615,9 +674,18 @@ class XmltvGenerator:
             return None
 
     def _add_enhanced_info_to_basic_desc(
-        self, base_desc: str, episode_data: Dict, language: str
+        self,
+        base_desc: str,
+        episode_data: Dict,
+        language: str,
+        include_season_episode: bool = False,
     ) -> str:
-        """Add enhanced info (with translations) to basic description"""
+        """
+        Add enhanced info (with translations) to basic description
+
+        Added parameter to control whether to include S##E## info
+        (default False as Kodi already displays this)
+        """
         try:
             # Build additional info with translations
             additional_info = []
@@ -626,8 +694,8 @@ class XmltvGenerator:
             if episode_data.get("epyear") and str(episode_data["epyear"]) != "0":
                 additional_info.append(str(episode_data["epyear"]))
 
-            # Add season/episode info for series
-            if episode_data.get("epsn") and episode_data.get("epen"):
+            # Add season/episode info ONLY if requested (by default NO as Kodi shows it)
+            if include_season_episode and episode_data.get("epsn") and episode_data.get("epen"):
                 try:
                     season_ep = f"S{int(episode_data['epsn']):02d}E{int(episode_data['epen']):02d}"
                     additional_info.append(season_ep)
@@ -710,7 +778,7 @@ class XmltvGenerator:
                 info_str = " | ".join(additional_info)
                 enhanced_description = f"{base_desc} • {info_str}"
                 logging.debug(
-                    "Enhanced description created for %s: added %d info items in %s",
+                    "Enhanced description created for %s: added %d info items in %s (S##E## excluded)",
                     episode_data.get("epshow", "Unknown"),
                     len(additional_info),
                     language,
